==> php-di_7.0.8.orig.tar.xz: php-di-7.0.8/tests/UnitTest/Definition/Resolver/InstanceInjectorTest.php <==
<?php

declare(strict_types=1);

namespace DI\Test\UnitTest\Definition\Resolver;

use DI\Definition\InstanceDefinition;
use DI\Definition\ObjectDefinition;
use DI\Definition\ObjectDefinition\MethodInjection;
use DI\Definition\ObjectDefinition\PropertyInjection;
use DI\Definition\Resolver\InstanceInjector;
use DI\Definition\Resolver\ResolverDispatcher;
use DI\Proxy\ProxyFactory;
use DI\Test\UnitTest\Definition\Resolver\Fixture\FixtureClass;
use EasyMock\EasyMock;
use PHPUnit\Framework\TestCase;

/**
 * @covers \DI\Definition\Resolver\InstanceInjector
 */
class InstanceInjectorTest extends TestCase
{
    use EasyMock;

    /**
     * @test
     */
    public function should_inject_properties_on_instance()
    {
        $instance = new FixtureClass('');

        $objectDefinition = new ObjectDefinition(get_class($instance));
        $objectDefinition->addPropertyInjection(new PropertyInjection('prop', 'value'));

        $resolver = $this->buildResolver();
        $resolver->resolve(new InstanceDefinition($instance, $objectDefinition));

        $this->assertEquals('value', $instance->prop);
    }

    /**
     * @test
     */
    public function should_inject_methods_on_instance()
    {
        $instance = new FixtureClass('');

        $objectDefinition = new ObjectDefinition(get_class($instance));
        $objectDefinition->addMethodInjection(new MethodInjection('method', ['value']));

        $resolver = $this->buildResolver();
        $resolver->resolve(new InstanceDefinition($instance, $objectDefinition));

        $this->assertEquals('value', $instance->methodParam1);
    }

    private function buildResolver(): InstanceInjector
    {
        /** @var ResolverDispatcher $resolverDispatcher */
        $resolverDispatcher = $this->easyMock(ResolverDispatcher::class);
        /** @var ProxyFactory $factory */
        $factory = $this->easyMock(ProxyFactory::class);

        return new InstanceInjector($resolverDispatcher, $factory);
    }
}

==> php-di_7.1.1.orig.tar.xz: php-di-7.1.1/tests/UnitTest/Definition/Resolver/InstanceInjectorTest.php <==
<?php

declare(strict_types=1);

namespace DI\Test\UnitTest\Definition\Resolver;

use DI\Definition\InstanceDefinition;
use DI\Definition\ObjectDefinition;
use DI\Definition\ObjectDefinition\MethodInjection;
use DI\Definition\ObjectDefinition\PropertyInjection;
use DI\Definition\Resolver\InstanceInjector;
use DI\Definition\Resolver\ResolverDispatcher;
use DI\Proxy\ProxyFactory;
use DI\Test\UnitTest\Definition\Resolver\Fixture\FixtureClass;
use EasyMock\EasyMock;
use PHPUnit\Framework\TestCase;

/**
 * @covers \DI\Definition\Resolver\InstanceInjector
 */
#[\PHPUnit\Framework\Attributes\CoversClass(\DI\Definition\Resolver\InstanceInjector::class)]
class InstanceInjectorTest extends TestCase
{
    use EasyMock;

    /**
     * @test
     */
    #[\PHPUnit\Framework\Attributes\Test]
    public function should_inject_properties_on_instance()
    {
        $instance = new FixtureClass('');

        $objectDefinition = new ObjectDefinition(get_class($instance));
        $objectDefinition->addPropertyInjection(new PropertyInjection('prop', 'value'));

        $resolver = $this->buildResolver();
        $resolver->resolve(new InstanceDefinition($instance, $objectDefinition));

        $this->assertEquals('value', $instance->prop);
    }

    /**
     * @test
     */
    #[\PHPUnit\Framework\Attributes\Test]
    public function should_inject_methods_on_instance()
    {
        $instance = new FixtureClass('');

        $objectDefinition = new ObjectDefinition(get_class($instance));
        $objectDefinition->addMethodInjection(new MethodInjection('method', ['value']));

        $resolver = $this->buildResolver();
        $resolver->resolve(new InstanceDefinition($instance, $objectDefinition));

        $this->assertEquals('value', $instance->methodParam1);
    }

    private function buildResolver(): InstanceInjector
    {
        /** @var ResolverDispatcher $resolverDispatcher */
        $resolverDispatcher = $this->easyMock(ResolverDispatcher::class);
        /** @var ProxyFactory $factory */
        $factory = $this->easyMock(ProxyFactory::class);

        return new InstanceInjector($resolverDispatcher, $factory);
    }
}
